import rclpy
from rclpy.node import Node

from geometry_msgs.msg import Twist
from std_msgs.msg import String
from sensor_msgs.msg import Joy

import numpy as np

SCALE_LINEAR_VELOCITY = 0.5
SCALE_ANGULAR_VELOCITY = 0.4
PUBLISH_FREQUENCY_HZ = 10


def calc_speed_from_joy(x, y):    
    linear = -y * SCALE_LINEAR_VELOCITY
    angular = x * SCALE_ANGULAR_VELOCITY

    return linear, angular

class TwistPublisher(Node):

    def __init__(self):
        super().__init__('twist_publisher')
        self.linear = 0.0
        self.angular = 0.0
        self.publisher_ = self.create_publisher(Twist, '/diff_cont/cmd_vel_unstamped', 1)
        self.create_subscription(Joy, "/joy", self.joy_callback, 1)
        self.timer = self.create_timer(1/PUBLISH_FREQUENCY_HZ, self.timer_callback)


    def joy_callback(self, joy_message):
        x, y = joy_message.axes[:2]

        self.linear, self.angular = calc_speed_from_joy(x,y)

    def timer_callback(self):
        msg = Twist()
        msg.linear.x = self.linear
        msg.angular.z = self.angular
        self.publisher_.publish(msg)
        self.get_logger().info('Publishing: "%s"' % msg)


def main(args=None):
    rclpy.init(args=args)

    minimal_publisher = TwistPublisher()

    rclpy.spin(minimal_publisher)

    # Destroy the node explicitly
    # (optional - otherwise it will be done automatically
    # when the garbage collector destroys the node object)
    minimal_publisher.destroy_node()
    rclpy.shutdown()


if __name__ == '__main__':
    main()