#include "communication/UCommands.hpp"
#include "misc/Utils.hpp"
#include "R2WD.h"
extern R2WD _2WD;

void UCommands::setSetpoint (uint8_t* d, U_Component c)
{
	float speed1 = Utils::bytesToFloat(d[COMMAND_POS + 1],
									  d[COMMAND_POS + 2],
									  d[COMMAND_POS + 3],
									  d[COMMAND_POS + 4]);
	switch (c) {
		case ALL_MOTORS: {
			float speed2 = Utils::bytesToFloat(d[COMMAND_POS + 5],
											d[COMMAND_POS + 6],
											d[COMMAND_POS + 7],
											d[COMMAND_POS + 8]);
			_2WD.wheelLeftSetSpeedMMPS(abs(speed1*1000), speed1 > 0 ? DIR_BACKOFF : DIR_ADVANCE);
			_2WD.wheelRightSetSpeedMMPS(abs(speed2*1000), speed2 > 0 ? DIR_ADVANCE : DIR_BACKOFF);
			break;
		}
		case RIGHT_MOTOR: {
			_2WD.wheelLeftSetSpeedMMPS(abs(speed1*1000), speed1 > 0 ? DIR_BACKOFF : DIR_ADVANCE);
			break;
		}
		case LEFT_MOTOR: {
			_2WD.wheelRightSetSpeedMMPS(abs(speed1*1000), speed1 > 0 ? DIR_ADVANCE : DIR_BACKOFF);
			break;
		}
		default: {
			break;
		}
	}
}

void UCommands::setPIDParameter (uint8_t* d, U_Component c)
{
	float P = Utils::bytesToFloat(d[COMMAND_POS + 1],
									  d[COMMAND_POS + 2],
									  d[COMMAND_POS + 3],
									  d[COMMAND_POS + 4]);
	float I = Utils::bytesToFloat(d[COMMAND_POS + 5],
									  d[COMMAND_POS + 6],
									  d[COMMAND_POS + 7],
									  d[COMMAND_POS + 8]);
	float D = Utils::bytesToFloat(d[COMMAND_POS + 9],
									  d[COMMAND_POS + 10],
									  d[COMMAND_POS + 11],
									  d[COMMAND_POS + 12]);
	switch (c) {
		case ALL_MOTORS: {
			_2WD.PIDTune(P,I,D,10);
			break;
		}
		case RIGHT_MOTOR: {
			_2WD.wheelLeftPIDTune(P,I,D,10);
			break;
		}
		case LEFT_MOTOR: {
			_2WD.wheelRightPIDTune(P,I,D,10);
			break;
		}
		default: {
			break;
		}
	}
}